@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator;
-$DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::VERSION = '0.002230';
-use Moo;
+$DBIx::Class::DeploymentHandler::DeployMethod::SQL::Translator::VERSION = '0.002231';
+use Moose;
 
 # ABSTRACT: Manage your SQL and Perl migrations in nicely laid out directories
 
@@ -9,22 +9,27 @@ use Carp qw( carp croak );
 use DBIx::Class::DeploymentHandler::LogImporter qw(:log :dlog);
 use Context::Preserve;
 use Digest::MD5;
+
 use Try::Tiny;
+
 use SQL::Translator;
 require SQL::Translator::Diff;
-use DBIx::Class::DeploymentHandler::Types -all;
-use IO::All;
+
+require DBIx::Class::Storage;   # loaded for type constraint
+use DBIx::Class::DeploymentHandler::Types;
+
+use Path::Class qw(file dir);
 
 with 'DBIx::Class::DeploymentHandler::HandlesDeploy';
 
 has ignore_ddl => (
-  isa      => Bool,
+  isa      => 'Bool',
   is       => 'ro',
   default  => undef,
 );
 
 has force_overwrite => (
-  isa      => Bool,
+  isa      => 'Bool',
   is       => 'ro',
   default  => undef,
 );
@@ -35,8 +40,9 @@ has schema => (
 );
 
 has storage => (
-  isa        => InstanceOf['DBIx::Class::Storage'],
-  is         => 'lazy',
+  isa        => 'DBIx::Class::Storage',
+  is         => 'ro',
+  lazy_build => 1,
 );
 
 has version_source => (
@@ -52,14 +58,12 @@ sub _build_storage {
 }
 
 has sql_translator_args => (
-  isa => HashRef,
+  isa => 'HashRef',
   is  => 'ro',
   default => sub { {} },
 );
-
 has script_directory => (
-  isa      => DirObject,
-  coerce   => 1,
+  isa      => 'Str',
   is       => 'ro',
   required => 1,
   default  => 'sql',
@@ -67,48 +71,65 @@ has script_directory => (
 
 has databases => (
   coerce  => 1,
-  isa     => Databases,
+  isa     => 'DBIx::Class::DeploymentHandler::Databases',
   is      => 'ro',
   default => sub { [qw( MySQL SQLite PostgreSQL )] },
 );
 
 has txn_wrap => (
   is => 'ro',
-  isa => Bool,
+  isa => 'Bool',
   default => 1,
 );
 
 has schema_version => (
-  coerce  => 1,
-  isa     => VersionNonObj,
-  is      => 'lazy',
+  is => 'ro',
+  lazy_build => 1,
 );
 
 # this will probably never get called as the DBICDH
 # will be passing down a schema_version normally, which
 # is built the same way, but we leave this in place
-sub _build_schema_version { $_[0]->schema->schema_version }
+sub _build_schema_version {
+  my $self = shift;
+  $self->schema->schema_version
+}
 
 sub __ddl_consume_with_prefix {
   my ($self, $type, $versions, $prefix) = @_;
   my $base_dir = $self->script_directory;
-  my $main = $base_dir->catdir( $type );
-  my $common = $base_dir->catdir( '_common', $prefix, join q(-), @{$versions} );
-  my $common_any = $base_dir->catdir( '_common', $prefix, '_any' );
-  my $dir_any = $main->catdir( $prefix, '_any');
+
+  my $main    = dir( $base_dir, $type      );
+  my $common  =
+    dir( $base_dir, '_common', $prefix, join q(-), @{$versions} );
+
+  my $common_any  =
+    dir( $base_dir, '_common', $prefix, '_any' );
+
+  my $dir_any = dir($main, $prefix, '_any');
+
   my %files;
   try {
-     my $dir = $main->catdir( $prefix, join q(-), @{$versions} );
+     my $dir = dir( $main, $prefix, join q(-), @{$versions} );
+     opendir my($dh), $dir;
      %files =
-       map { $_->filename => $_ }
-       grep /\.(?:sql|pl|sql-\w+)$/,
-       $dir->all_files;
+       map { $_ => "$dir/$_" }
+       grep { /\.(?:sql|pl|sql-\w+)$/ && -f "$dir/$_" }
+       readdir $dh;
+     closedir $dh;
   } catch {
     die $_ unless $self->ignore_ddl;
   };
-  for my $dir (grep $_->exists, $common, $common_any, $dir_any) {
-    $files{$_->filename} ||= $_ for grep /\.(?:sql|pl)$/, $dir->all_files;
+  for my $dirname (grep { -d $_ } $common, $common_any, $dir_any) {
+    opendir my($dh), $dirname;
+    for my $filename (grep { /\.(?:sql|pl)$/ && -f file($dirname,$_) } readdir $dh) {
+      unless ($files{$filename}) {
+        $files{$filename} = file($dirname,$filename);
+      }
+    }
+    closedir $dh;
   }
+
   return [@files{sort keys %files}]
 }
 
@@ -124,43 +145,98 @@ sub _ddl_schema_consume_filenames {
 
 sub _ddl_protoschema_deploy_consume_filenames {
   my ($self, $version) = @_;
-  my $dir = $self->script_directory->catdir('_source', 'deploy', $version);
-  return [] unless $dir->exists;
-  return [grep /\.yml$/, $dir->all_files];
+  my $base_dir = $self->script_directory;
+
+  my $dir = dir( $base_dir, '_source', 'deploy', $version);
+  return [] unless -d $dir;
+
+  opendir my($dh), $dir;
+  my %files = map { $_ => "$dir/$_" } grep { /\.yml$/ && -f "$dir/$_" } readdir $dh;
+  closedir $dh;
+
+  return [@files{sort keys %files}]
 }
 
-sub _ddl_protoschema_changegrade_consume_filenames {
-  my ($self, $versions, $direction) = @_;
-  my $dir = $self->script_directory->catdir('_preprocess_schema', $direction, join q(-), @{$versions});
-  return [] unless $dir->exists;
-  return [grep /\.pl$/, $dir->all_files];
+sub _ddl_protoschema_upgrade_consume_filenames {
+  my ($self, $versions) = @_;
+  my $base_dir = $self->script_directory;
+
+  my $dir = dir( $base_dir, '_preprocess_schema', 'upgrade', join q(-), @{$versions});
+
+  return [] unless -d $dir;
+
+  opendir my($dh), $dir;
+  my %files = map { $_ => "$dir/$_" } grep { /\.pl$/ && -f "$dir/$_" } readdir $dh;
+  closedir $dh;
+
+  return [@files{sort keys %files}]
+}
+
+sub _ddl_protoschema_downgrade_consume_filenames {
+  my ($self, $versions) = @_;
+  my $base_dir = $self->script_directory;
+
+  my $dir = dir( $base_dir, '_preprocess_schema', 'downgrade', join q(-), @{$versions});
+
+  return [] unless -d $dir;
+
+  opendir my($dh), $dir;
+  my %files = map { $_ => "$dir/$_" } grep { /\.pl$/ && -f "$dir/$_" } readdir $dh;
+  closedir $dh;
+
+  return [@files{sort keys %files}]
 }
 
 sub _ddl_protoschema_produce_filename {
   my ($self, $version) = @_;
-  my $dir = $self->script_directory->catdir('_source', 'deploy',  $version);
-  $dir->mkpath unless $dir->exists;
-  return $dir->catfile( '001-auto.yml' );
+  my $dirname = dir( $self->script_directory, '_source', 'deploy',  $version );
+  $dirname->mkpath unless -d $dirname;
+
+  return "" . file( $dirname, '001-auto.yml' );
 }
 
 sub _ddl_schema_produce_filename {
   my ($self, $type, $version) = @_;
-  my $dir = $self->script_directory->catdir($type, 'deploy', $version);
-  $dir->mkpath unless $dir->exists;
-  return $dir->catfile( '001-auto.sql' );
+  my $dirname = dir( $self->script_directory, $type, 'deploy', $version );
+  $dirname->mkpath unless -d $dirname;
+
+  return "" . file( $dirname, '001-auto.sql' );
 }
 
-sub _ddl_schema_changegrade_produce_filename {
-  my ($self, $type, $versions, $direction) = @_;
-  my $dir = $self->script_directory->catdir($type, $direction, join q(-), @{$versions});
-  $dir->mkpath unless $dir->exists;
-  return $dir->catfile( '001-auto.sql' );
+sub _ddl_schema_upgrade_consume_filenames {
+  my ($self, $type, $versions) = @_;
+  $self->__ddl_consume_with_prefix($type, $versions, 'upgrade')
+}
+
+sub _ddl_schema_downgrade_consume_filenames {
+  my ($self, $type, $versions) = @_;
+  $self->__ddl_consume_with_prefix($type, $versions, 'downgrade')
+}
+
+sub _ddl_schema_upgrade_produce_filename {
+  my ($self, $type, $versions) = @_;
+  my $dir = $self->script_directory;
+
+  my $dirname = dir( $dir, $type, 'upgrade', join q(-), @{$versions});
+  $dirname->mkpath unless -d $dirname;
+
+  return "" . file( $dirname, '001-auto.sql' );
+}
+
+sub _ddl_schema_downgrade_produce_filename {
+  my ($self, $type, $versions, $dir) = @_;
+  my $dirname = dir( $dir, $type, 'downgrade', join q(-), @{$versions} );
+  $dirname->mkpath unless -d $dirname;
+
+  return "" . file( $dirname, '001-auto.sql');
 }
 
 sub _run_sql_array {
   my ($self, $sql) = @_;
   my $storage = $self->storage;
+
   $sql = [ $self->_split_sql_chunk( @$sql ) ];
+
   Dlog_trace { "Running SQL $_" } $sql;
   foreach my $line (@{$sql}) {
     $storage->_query_start($line);
@@ -298,7 +374,7 @@ sub _run_sql {
   my ($self, $filename) = @_;
   log_debug { "Running SQL from $filename" };
   try {
-     $self->_run_sql_array([ $self->_split_sql_chunk( $$filename ) ]);
+     $self->_run_sql_array($self->_read_sql_file($filename));
   } catch {
      die "failed to run SQL in $filename: $_"
   };
@@ -307,22 +383,30 @@ sub _run_sql {
 my ( %f2p, %p2f );
 sub _generate_script_package_name {
     my $file = shift;
+
     my $pkgbase = 'DBICDH::Sandbox::';
     my $maxlen = 200;    # actual limit is "about 250" according to perldiag
+
     return $pkgbase . $f2p{"$file"} if $f2p{"$file"};
+
     my $package = Digest::MD5::md5_hex("$file");
     $package++ while exists $p2f{$package};    # increment until unique
+
     die "unable to generate a unique short name for '$file'"
       if length($pkgbase) + length($package) > $maxlen;
+
     $f2p{"$file"} = $package;
     $p2f{$package} = "$file";
+
     return $pkgbase . $package;
 }
 
 sub _load_sandbox {
   my $_file = shift;
   $_file = "$_file";
+
   my $_package = _generate_script_package_name($_file);
+
   my $fn = eval sprintf <<'END_EVAL', $_package;
 package %s;
 {
@@ -332,17 +416,23 @@ package %s;
   $app;
 }
 END_EVAL
+
   croak $@ if $@;
+
   croak "$_file should define an anonymous sub that takes a schema but it didn't!"
      unless ref $fn && ref $fn eq 'CODE';
+
   return $fn;
 }
 
 sub _run_perl {
   my ($self, $filename, $versions) = @_;
   log_debug { "Running Perl from $filename" };
+
   my $fn = _load_sandbox($filename);
+
   Dlog_trace { "Running Perl $_" } $fn;
+
   try {
      $fn->($self->schema, $versions)
   } catch {
@@ -353,7 +443,9 @@ sub _run_perl {
 sub txn_do {
    my ( $self, $code ) = @_;
    return $code->() unless $self->txn_wrap;
+
    my $guard = $self->schema->txn_scope_guard;
+
    return preserve_context { $code->() } after => sub { $guard->commit };
 }
 
@@ -362,20 +454,21 @@ sub _run_sql_and_perl {
   my @files   = @{$filenames};
   $self->txn_do(sub {
      $self->_run_sql_array($sql_to_run) if $self->ignore_ddl;
+
      my $sql = ($sql_to_run)?join ";\n", @$sql_to_run:'';
      FILENAME:
-     for my $filename (@files) {
-       if ($self->ignore_ddl && $filename =~ /^[^-]*-auto.*\.sql$/) {
+     for my $filename (map file($_), @files) {
+       if ($self->ignore_ddl && $filename->basename =~ /^[^-]*-auto.*\.sql$/) {
          next FILENAME
        } elsif ($filename =~ /\.sql$/) {
           $sql .= $self->_run_sql($filename)
        } elsif ( $filename =~ /\.pl$/ ) {
           $self->_run_perl($filename, $versions)
        } else {
-         # uncoverable statement
          croak "A file ($filename) got to deploy that wasn't sql or perl!";
        }
      }
+
      return $sql;
   });
 }
@@ -404,17 +497,21 @@ sub initialize {
   my $version      = $args->{version}      || $self->schema_version;
   log_info { "initializing version $version" };
   my $storage_type = $args->{storage_type} || $self->storage->sqlt_type;
+
   my @files = @{$self->_ddl_initialize_consume_filenames(
     $storage_type,
     $version,
   )};
+
   for my $filename (@files) {
     # We ignore sql for now (till I figure out what to do with it)
     if ( $filename =~ /^(.+)\.pl$/ ) {
-      my $filedata = $$filename;
+      my $filedata = do { local( @ARGV, $/ ) = $filename; <> };
+
       no warnings 'redefine';
-      my $fn = eval $filedata;
+      my $fn = eval "$filedata";
       use warnings;
+
       if ($@) {
         croak "$filename failed to compile: $@";
       } elsif (ref $fn eq 'CODE') {
@@ -423,7 +520,6 @@ sub initialize {
         croak "$filename should define an anonymous sub but it didn't!";
       }
     } else {
-      # uncoverable statement
       croak "A file ($filename) got to initialize_scripts that wasn't sql or perl!";
     }
   }
@@ -431,37 +527,71 @@ sub initialize {
 
 sub _sqldiff_from_yaml {
   my ($self, $from_version, $to_version, $db, $direction) = @_;
+  my $dir       = $self->script_directory;
   my $sqltargs = {
     add_drop_table => 0,
     ignore_constraint_names => 1,
     ignore_index_names => 1,
     %{$self->sql_translator_args}
   };
-  my @schemas; # source, dest
-  for ([ $from_version, 'previous' ], [ $to_version, 'next' ]) {
-    my ($version, $label) = @$_;
-    my $file = $self->_ddl_protoschema_produce_filename($version);
+
+  my $source_schema;
+  {
+    my $prefilename = $self->_ddl_protoschema_produce_filename($from_version, $dir);
+
     # should probably be a croak
-    carp("No $label schema file found ($file)")
-       unless $file->exists;
+    carp("No previous schema file found ($prefilename)")
+       unless -e $prefilename;
+
     my $t = SQL::Translator->new({
-       %$sqltargs,
+       %{$sqltargs},
        debug => 0,
        trace => 0,
        parser => 'SQL::Translator::Parser::YAML',
     });
-    my $out = $t->translate( $file . '' ) or croak($t->error);
-    my $schema = $t->schema;
-    $schema->name( $file ) unless $schema->name;
-    push @schemas, $schema;
+
+    my $out = $t->translate( $prefilename )
+      or croak($t->error);
+
+    $source_schema = $t->schema;
+
+    $source_schema->name( $prefilename )
+      unless  $source_schema->name;
   }
+
+  my $dest_schema;
+  {
+    my $filename = $self->_ddl_protoschema_produce_filename($to_version, $dir);
+
+    # should probably be a croak
+    carp("No next schema file found ($filename)")
+       unless -e $filename;
+
+    my $t = SQL::Translator->new({
+       %{$sqltargs},
+       debug => 0,
+       trace => 0,
+       parser => 'SQL::Translator::Parser::YAML',
+    });
+
+    my $out = $t->translate( $filename )
+      or croak($t->error);
+
+    $dest_schema = $t->schema;
+
+    $dest_schema->name( $filename )
+      unless $dest_schema->name;
+  }
+
+  my $transform_files_method =  "_ddl_protoschema_${direction}_consume_filenames";
   my $transforms = $self->_coderefs_per_files(
-    $self->_ddl_protoschema_changegrade_consume_filenames([$from_version, $to_version], $direction)
+    $self->$transform_files_method([$from_version, $to_version])
   );
-  $_->(@schemas) for @$transforms;
+  $_->($source_schema, $dest_schema) for @$transforms;
+
   return [SQL::Translator::Diff::schema_diff(
-     $schemas[0], $db,
-     $schemas[1], $db,
+     $source_schema, $db,
+     $dest_schema,   $db,
      { producer_args => $sqltargs }
   )];
 }
@@ -470,12 +600,13 @@ sub _sql_from_yaml {
   my ($self, $sqltargs, $from_file, $db) = @_;
   my $schema    = $self->schema;
   my $version   = $self->schema_version;
+
   my @sql;
+
   my $actual_file = $self->$from_file($version);
   for my $yaml_filename (@{(
-     # uncoverable statement
      DlogS_trace { "generating SQL from Serialized SQL Files: $_" }
-        (ref $actual_file eq 'ARRAY'?$actual_file:[$actual_file])
+        (ref $actual_file?$actual_file:[$actual_file])
   )}) {
      my $sqlt = SQL::Translator->new({
        add_drop_table          => 0,
@@ -483,9 +614,9 @@ sub _sql_from_yaml {
        %{$sqltargs},
        producer => $db,
      });
-     push @sql, $sqlt->translate($yaml_filename.'');
+
+     push @sql, $sqlt->translate($yaml_filename);
      if(!@sql) {
-       # uncoverable statement count:2
        carp("Failed to translate to $db, skipping. (" . $sqlt->error . ")");
        return undef;
      }
@@ -498,12 +629,26 @@ sub _prepare_install {
   my $sqltargs  = { %{$self->sql_translator_args}, %{shift @_} };
   my $from_file = shift;
   my $to_file   = shift;
+  my $dir       = $self->script_directory;
   my $databases = $self->databases;
   my $version   = $self->schema_version;
+
   foreach my $db (@$databases) {
     my $sql = $self->_sql_from_yaml($sqltargs, $from_file, $db ) or next;
-    my $file = $self->$to_file($db, $version);
-    $self->_maybe_overwrite('DDL', $file, join ";\n", @$sql, '');
+
+    my $filename = $self->$to_file($db, $version, $dir);
+    if (-e $filename ) {
+      if ($self->force_overwrite) {
+         carp "Overwriting existing DDL file - $filename";
+         unlink $filename;
+      } else {
+         die "Cannot overwrite '$filename', either enable force_overwrite or delete it"
+      }
+    }
+    open my $file, q(>), $filename;
+    binmode $file;
+    print {$file} join ";\n", @$sql, '';
+    close $file;
   }
 }
 
@@ -511,9 +656,10 @@ sub _resultsource_install_filename {
   my ($self, $source_name) = @_;
   return sub {
     my ($self, $type, $version) = @_;
-    my $dir = $self->script_directory->catdir($type, 'deploy', $version);
-    $dir->mkpath unless $dir->exists;
-    return $dir->catfile( "001-auto-$source_name.sql" );
+    my $dirname = dir( $self->script_directory, $type, 'deploy', $version );
+    $dirname->mkpath unless -d $dirname;
+
+    return "" . file( $dirname, "001-auto-$source_name.sql" );
   }
 }
 
@@ -521,9 +667,10 @@ sub _resultsource_protoschema_filename {
   my ($self, $source_name) = @_;
   return sub {
     my ($self, $version) = @_;
-    my $dir = $self->script_directory->catdir('_source', 'deploy', $version);
-    $dir->mkpath unless $dir->exists;
-    return $dir->catfile( "001-auto-$source_name.yml" );
+    my $dirname = dir( $self->script_directory, '_source', 'deploy', $version );
+    $dirname->mkpath unless -d $dirname;
+
+    return "" . file( $dirname, "001-auto-$source_name.yml" );
   }
 }
 
@@ -536,6 +683,7 @@ sub install_resultsource {
   log_info { 'installing_resultsource ' . $source->source_name . ", version $version" };
   my $rs_install_file =
     $self->_resultsource_install_filename($source->source_name);
+
   my $files = [
      $self->$rs_install_file(
       $self->storage->sqlt_type,
@@ -549,6 +697,7 @@ sub prepare_resultsource_install {
   my $self = shift;
   my $source = (shift @_)->{result_source};
   log_info { 'preparing install for resultsource ' . $source->source_name };
+
   my $install_filename = $self->_resultsource_install_filename($source->source_name);
   my $proto_filename = $self->_resultsource_protoschema_filename($source->source_name);
   $self->prepare_protoschema({
@@ -574,60 +723,102 @@ sub prepare_deploy {
 }
 
 sub prepare_upgrade {
-  push @_, 'upgrade';
-  goto &_prepare_changegrade;
+  my ($self, $args) = @_;
+  log_info {
+     "preparing upgrade from $args->{from_version} to $args->{to_version}"
+  };
+  $self->_prepare_changegrade(
+    $args->{from_version}, $args->{to_version}, $args->{version_set}, 'upgrade'
+  );
 }
 
 sub prepare_downgrade {
-  push @_, 'downgrade';
-  goto &_prepare_changegrade;
+  my ($self, $args) = @_;
+  log_info {
+     "preparing downgrade from $args->{from_version} to $args->{to_version}"
+  };
+  $self->_prepare_changegrade(
+    $args->{from_version}, $args->{to_version}, $args->{version_set}, 'downgrade'
+  );
 }
 
 sub _coderefs_per_files {
   my ($self, $files) = @_;
   no warnings 'redefine';
-  [map eval $$_, @$files]
+  [map eval do { local( @ARGV, $/ ) = $_; <> }, @$files]
 }
 
 sub _prepare_changegrade {
-  my ($self, $args, $direction) = @_;
-  log_info {
-     "preparing $direction from $args->{from_version} to $args->{to_version}"
-  };
-  foreach my $db (@{ $self->databases }) {
-    my $file = $self->_ddl_schema_changegrade_produce_filename($db, $args->{version_set}, $direction);
-    $self->_maybe_overwrite("$direction-diff", $file,
-      join ";\n", @{$self->_sqldiff_from_yaml(@$args{qw(from_version to_version)}, $db, $direction)}
-    );
+  my ($self, $from_version, $to_version, $version_set, $direction) = @_;
+  my $schema    = $self->schema;
+  my $databases = $self->databases;
+  my $dir       = $self->script_directory;
+
+  my $schema_version = $self->schema_version;
+  my $diff_file_method = "_ddl_schema_${direction}_produce_filename";
+  foreach my $db (@$databases) {
+    my $diff_file = $self->$diff_file_method($db, $version_set, $dir );
+    if(-e $diff_file) {
+      if ($self->force_overwrite) {
+         carp("Overwriting existing $direction-diff file - $diff_file");
+         unlink $diff_file;
+      } else {
+         die "Cannot overwrite '$diff_file', either enable force_overwrite or delete it"
+      }
+    }
+
+    open my $file, q(>), $diff_file;
+    binmode $file;
+    print {$file} join ";\n", @{$self->_sqldiff_from_yaml($from_version, $to_version, $db, $direction)};
+    close $file;
   }
 }
 
+sub _read_sql_file {
+  my ($self, $file)  = @_;
+  return unless $file;
+
+   local $/ = undef;  #sluuuuuurp
+
+  open my $fh, '<', $file;
+  return [ $self->_split_sql_chunk( <$fh> ) ];
+}
+
 sub downgrade_single_step {
-  push @_, 'downgrade';
-  goto &_changegrade_single_step;
-}
-
-sub upgrade_single_step {
-  push @_, 'upgrade';
-  goto &_changegrade_single_step;
-}
-
-sub _changegrade_single_step {
   my $self = shift;
   my $version_set = (shift @_)->{version_set};
-  my $direction = shift;
-  Dlog_info { "${direction}_single_step'ing $_" } $version_set;
+  Dlog_info { "downgrade_single_step'ing $_" } $version_set;
+
   my $sqlt_type = $self->storage->sqlt_type;
   my $sql_to_run;
   if ($self->ignore_ddl) {
      $sql_to_run = $self->_sqldiff_from_yaml(
-       $version_set->[0], $version_set->[1], $sqlt_type, $direction,
+       $version_set->[0], $version_set->[1], $sqlt_type, 'downgrade',
      );
   }
-  my $sql = $self->_run_sql_and_perl($self->__ddl_consume_with_prefix(
+  my $sql = $self->_run_sql_and_perl($self->_ddl_schema_downgrade_consume_filenames(
+    $sqlt_type,
+    $version_set,
+  ), $sql_to_run, $version_set);
+
+  return ['', $sql];
+}
+
+sub upgrade_single_step {
+  my $self = shift;
+  my $version_set = (shift @_)->{version_set};
+  Dlog_info { "upgrade_single_step'ing $_" } $version_set;
+
+  my $sqlt_type = $self->storage->sqlt_type;
+  my $sql_to_run;
+  if ($self->ignore_ddl) {
+     $sql_to_run = $self->_sqldiff_from_yaml(
+       $version_set->[0], $version_set->[1], $sqlt_type, 'upgrade',
+     );
+  }
+  my $sql = $self->_run_sql_and_perl($self->_ddl_schema_upgrade_consume_filenames(
     $sqlt_type,
     $version_set,
-    $direction,
   ), $sql_to_run, $version_set);
   return ['', $sql];
 }
@@ -636,7 +827,9 @@ sub prepare_protoschema {
   my $self      = shift;
   my $sqltargs  = { %{$self->sql_translator_args}, %{shift @_} };
   my $to_file   = shift;
-  my $file = $self->$to_file($self->schema_version);
+  my $filename
+    = $self->$to_file($self->schema_version);
+
   # we do this because the code that uses this sets parser args,
   # so we just need to merge in the package
   my $sqlt = SQL::Translator->new({
@@ -644,24 +837,25 @@ sub prepare_protoschema {
     producer                => 'SQL::Translator::Producer::YAML',
     %{ $sqltargs },
   });
-  my $yml = $sqlt->translate(data => $self->schema)
-    or croak "Failed to translate to YAML: " . $sqlt->error;
-  $self->_maybe_overwrite('DDL-YML', $file, $yml);
-}
 
-sub _maybe_overwrite {
-  my ($self, $label, $file, $content) = @_;
-  if ($file->exists) {
+  my $yml = $sqlt->translate(data => $self->schema);
+
+  croak("Failed to translate to YAML: " . $sqlt->error)
+    unless $yml;
+
+  if (-e $filename ) {
     if ($self->force_overwrite) {
-       # uncoverable statement count:2
-       carp "Overwriting existing $label file - $file";
-       unlink $file;
+       carp "Overwriting existing DDL-YML file - $filename";
+       unlink $filename;
     } else {
-       die "Cannot overwrite '$file', either enable force_overwrite or delete it";
+       die "Cannot overwrite '$filename', either enable force_overwrite or delete it"
     }
   }
-  $file->binmode;
-  $file->print($content);
+
+  open my $file, q(>), $filename;
+  binmode $file;
+  print {$file} $yml;
+  close $file;
 }
 
 __PACKAGE__->meta->make_immutable;
