@@ -1,31 +1,26 @@
 package DBIx::Class::DeploymentHandler::Types;
-$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002230';
+$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002231';
 use strict;
 use warnings;
-use IO::All;
 
 # ABSTRACT: Types internal to DBIx::Class::DeploymentHandler
 
-use Type::Library
-  -base,
-  -declare => qw( Databases VersionNonObj DirObject );
-use Type::Utils -all;
-BEGIN { extends "Types::Standard" };
+use Moose::Util::TypeConstraints;
+subtype 'DBIx::Class::DeploymentHandler::Databases'
+ => as 'ArrayRef[Str]';
 
-declare Databases, as ArrayRef[Str];
+coerce 'DBIx::Class::DeploymentHandler::Databases'
+ => from 'Str'
+ => via { [$_] };
 
-coerce Databases,
-  from Str, via { [ $_ ] };
+subtype 'DBIx::Class::DeploymentHandler::VersionNonObj'
+ => as 'Str';
 
-declare VersionNonObj, as Str;
-
-coerce VersionNonObj,
-  from InstanceOf['version'], via { $_->numify + 0 };
-
-declare DirObject, as InstanceOf['IO::All::Dir'];
-coerce DirObject,
-  from Str, via { io->dir($_) };
+coerce 'DBIx::Class::DeploymentHandler::VersionNonObj'
+ => from 'Object'
+ => via { $_->numify };
 
+no Moose::Util::TypeConstraints;
 1;
 
 # vim: ts=2 sw=2 expandtab
