@@ -1,7 +1,7 @@
 package DBIx::Class::DeploymentHandler::VersionHandler::Monotonic;
-$DBIx::Class::DeploymentHandler::VersionHandler::Monotonic::VERSION = '0.002230';
-use Moo;
-use DBIx::Class::DeploymentHandler::Types -all;
+$DBIx::Class::DeploymentHandler::VersionHandler::Monotonic::VERSION = '0.002231';
+use Moose;
+use DBIx::Class::DeploymentHandler::Types;
 
 # ABSTRACT: Obvious version progressions
 
@@ -10,22 +10,23 @@ use Carp 'croak';
 with 'DBIx::Class::DeploymentHandler::HandlesVersioning';
 
 has schema_version => (
-  isa      => VersionNonObj,
+  isa      => 'DBIx::Class::DeploymentHandler::VersionNonObj',
   coerce   => 1,
   is       => 'ro',
   required => 1,
 );
 
 has initial_version => (
-  isa      => Int,
+  isa      => 'Int',
   is       => 'ro',
   required => 1,
 );
 
 has to_version => (
-  isa        => VersionNonObj,
+  isa        => 'DBIx::Class::DeploymentHandler::VersionNonObj',
   coerce     => 1,
-  is         => 'lazy',
+  is         => 'ro',
+  lazy_build => 1,
 );
 
 sub _build_to_version {
@@ -35,9 +36,8 @@ sub _build_to_version {
 
 has _version => (
   is         => 'rw',
-  isa        => Int,
-  builder    => \&_build__version,
-  lazy       => 1,
+  isa        => 'Int',
+  lazy_build => 1,
 );
 
 sub _inc_version { $_[0]->_version($_[0]->_version + 1 ) }
