@@ -1,6 +1,6 @@
 package DBIx::Class::DeploymentHandler::WithReasonableDefaults;
-$DBIx::Class::DeploymentHandler::WithReasonableDefaults::VERSION = '0.002230';
-use Moo::Role;
+$DBIx::Class::DeploymentHandler::WithReasonableDefaults::VERSION = '0.002231';
+use Moose::Role;
 
 # ABSTRACT: Make default arguments to a few methods sensible
 
